@@ -1,5 +1,5 @@
 package IO::Pager::Perl;
-our $VERSION = '1.03'; #Untouched since 1.03
+our $VERSION = '2.00'; #Untouched since 2.00
 
 use strict;
 use warnings;
@@ -13,6 +13,7 @@ local $SIG{INT} = local $SIG{QUIT} = \&close;
 sub ReadMode;
 sub ReadKey;
 
+
 sub new {
   my $class = shift;
   my %param = @_;
@@ -72,7 +73,8 @@ sub new {
 		  _search => '',	_statCols => 0,    _lineNo=>[0],
 		  lineNo => 0,		pause => '',	   #pause=>"\cL" #more
 		  raw => 0,		statusCol => 0,	   squeeze=>0,
-		  visualBell=>0,	fold=>0,
+		  visualBell => 0,	fold => 0,         _fileN => 1,
+		  _mark => {1=>0},      scrollBar => 0,
 		  %dims,
 
 		  # if the termcap entries don't exist, nothing bad will happen
@@ -89,11 +91,11 @@ sub new {
   $me->add_text($text) if defined $text;
 
   $me->{_I18N}={
-		status=>		'',
+		prompt=>	'',
 		404=>		'Not Found',
 		top=>		'Top',
 		bottom=>	'Bottom',
-		prompt=>	"<h>=help \000<space>=down <b>=back <q>=quit",
+		minihelp=>	"<h>=help \000<space>=down <b>=back <q>=quit",
 		continue=>	'press any key to continue',
 		searchwrap=>    'No more matches, next search will wrap',
 		nowrap=>        'Text::Wrap unavailable, disabling folding',
@@ -157,10 +159,11 @@ EOH
 		'?' => \&hcraes,
 		"'" => \&goto_mark,
 		'#' => \&toggle_num,    #XXX Change toggle* to '-' initiated
-		'C' => \&toggle_raw,    #multi-key input mode like \d+ to
-		'S' => \&toggle_fold,   #mimic less?
+		'C' => \&toggle_raw,    #input mode like : to mimic less?
+		'S' => \&toggle_fold,
 		'R' => \&flush_buffer,
 		':w'=> \&write_buffer,
+		':e'=> \&open_file,
 	       );
   
   #Mise-en-place; prepare to cook some characters
@@ -169,15 +172,15 @@ EOH
 
   $me->{_end} = $me->{rows} - 1;
 
-  if( $me->{fold} ){
-    eval "use Text::Wrap";
-    $me->dialog($me->{_I18N}{nowrap} . "\n\n$@") if $@;
-  }
-  if( $@ or not $me->{fold} ){
-    sub wrap {@_}
-  }
-
   $SIG{WINCH} = sub{ $me->resize() };
+  $me->{cols}-- if $me->{scrollBar};
+
+  #Can we fold?
+  eval "use Text::Wrap";
+  if( $@ ){
+    sub wrap{ join '', @_ }
+    $me->{fold} = 0;
+  }
 
   $me;
 }
@@ -186,14 +189,24 @@ sub resize {
   my $me = shift;
   my %dims = get_size();
   $dims{rows}--;
+  $dims{cols}-- if $me->{scrollBar};
   $me->{$_} = $dims{$_} foreach keys %dims;
 
   $me->{_end} = $me->{rows} - 1;
 
-  $me->{fold} ? $me->reflow() : $me->refresh();
-  $me->prompt();
+  if( $me->{fold} ){
+    $me->reflow();
+    #XXX Crude attempt to mintain position,
+    #XXX only works if all rows folded same amount
+    #$me->jump( int($me->{_cursor} * $me->{cols) / $dims{cols})-1 );
+    #XXX need to somehow use _lineNo instead?
+  }
+  else{
+    $me->refresh();
+  }
+  $me->status();
 
-  $me->{WINCH}->() if ref($me->{WINCH}) eq 'CODE';
+  $me->{WINCH}->() if ref($me->{WINCH}) eq 'CODE';  
 }
 
 sub get_size {
@@ -342,7 +355,7 @@ sub more {
     #INPUT LOOP, revised with inspiration from Term::Screen::getch()
     #my $input=''; #TIGHT
     while( 1 ){
-      $me->prompt();					# status line
+      $me->status();					# status line
       my $exit = undef;
 
       my $char = ReadKey($param{RT});
@@ -350,10 +363,10 @@ sub more {
       #functionality and for cleaner startup (no preload on piped input)
       #next unless defined($char); #TIGHT
       return 1 unless defined($char);
-      $me->{_I18N}{status} = $input .= $char;
-      $me->prompt();
+      $me->{_I18N}{prompt} = $input .= $char;
+      $me->status();
 
-      unless( ($input=~ /^\e/ and index($me->{_fncRE}, $input)>0 )
+     unless( ($input=~ /^\e/ and index($me->{_fncRE}, $input)>0 )
 	      || $input =~ /^\d+/
 	      || $input =~ /:+/
 	      || defined($me->{_fnc}->{$input}) ){
@@ -367,33 +380,31 @@ sub more {
 	my $n = $me->{_fnc}->{$input};
 	$n = svref_2object($n)->GV->NAME;
 	$exit = $me->{_fnc}->{$input}->($me);
-	$me->{_I18N}{status} = $input = '';
+	$me->{_I18N}{prompt} = $input = '';
       }
       #vi-style input
       elsif( $input =~ /^:/ ){
 	if( ($char eq "\cG") or ($input eq '::') ){
-	  $me->{_I18N}{status} = $input = '';
-	  $me->prompt();
+	  $me->{_I18N}{prompt} = $input = '';
+	  $me->status();
 	  return 1; }
       }
-      #Line-number input
+      #Line-number input; would love to use getln, but does not mix w/ status
       elsif( $me->{_fnc}->{'/(\d+)/'} and $input =~ /^\d+/ ){
 	if( $char eq "\cH" or ord($char)==127 ){
-	  chop($input); chop($input); }
+	  $input = substr($input, 0, -2, ''); }
 	elsif( $char eq "\cG" ){
-	  $me->{_I18N}{status} = $input = '';
-	  $me->prompt();
-	  return 1; }
-	if( $input =~ /^\d+\n$/ ){
-	  chomp($input);
+	  $input = '';
+	  $exit = 1; }
+	elsif( $char eq "\n" ){
+	  #Remove extraneous characters that could cause infinite error loop
+	  #XXX this prevents goofy RPN-like repeated commands
+	  $input =~ y/0-9//cd;#	  chomp($input);
 	  $exit = $input < $me->{_txtN} ? $me->jump($input) : $me->to_bott();
-	  $me->{_I18N}{status} = $input = '';
-	  $me->prompt();
-	  next; }
-	#XXX need to do something here to handle no-decimal/bogus entry
-	else{
-	  $me->{_I18N}{status} = $input;
-	  $me->prompt(); }
+	  $input = ''; }
+
+	$me->{_I18N}{prompt} = $input;
+	$me->status();
       }
 
       return 1 if $param{RT} && defined($exit);
@@ -440,7 +451,7 @@ sub add_func{
   }
   #XXX RegExp::Trie, List::RegExp? #quotemeta?
   $me->{_fncRE} = join '|', sort keys %{ $me->{_fnc} };
-  #$me->{_fncRE} = qr/^($me->{_fncRE})/;
+  #$me->{_fncRE} = qr/^($me->{_fncRE})$/;
 }
 
 sub beep{
@@ -451,11 +462,36 @@ sub beep{
     $_[1] =~ s/\e/^[/;
     $_[1] =~ s/([^[:print:]])/sprintf("\\%03o", ord($1))/ge; #Cook
     $_[0]->dialog("Unrecognized command: $_[1]", 1);
+
+    $_[0]->{_I18N}{prompt} = '';
+    $_[0]->status();
   }
 }
 
-# display a prompt, etc
-sub prompt{
+sub getln{
+  my $input;
+  while(1){
+    my $l = ReadKey();
+    last if $l eq "\n" || $l eq "\r";
+
+    if( !defined($l)| $l eq "\e" || $l eq "\cG" ){
+      $input = '';
+      last; }
+    elsif( $l eq "\b" || $l eq "\177" ){
+      print "\b \b" if $input ne '';
+      substr($input, -1, 1, '');
+      next;
+    }
+
+    print $l;
+    $input .= $l;
+  }
+  return $input;
+}
+
+
+# display a minihelp, etc
+sub status{
   my $me = shift;
   $me->{_txtN} ||= 0;
 
@@ -466,17 +502,17 @@ sub prompt{
     ($pct==1 ? $me->{_I18N}{bottom} : 'L'.$me->{_cursor}) :
 	       $me->{_I18N}{top};
   $pos .= 'C'.$me->{_left} if $me->{_left};
-  my $p = sprintf "[tp] %d%% %s %s", 100*$pct, $pos, $me->{_I18N}{status};
+  my $p = sprintf "[tp] %d%% %s %s", 100*$pct, $pos, $me->{_I18N}{prompt};
 
   print $me->{_term}->Tgoto('cm', 0, $me->{rows});	# bottom left
   print $me->{_term}->Tputs('ce');			# clear line
-  my $prompt = $me->{_I18N}{prompt};
+  my $minihelp = $me->{_I18N}{minihelp};
   (my $pSansCodes = $p) =~ s/\e\[[\d;]*[a-zA-Z]//g;
-  my $pN = $me->{cols} - 2 - length($pSansCodes) - length($me->{_I18N}{prompt});
+  my $pN = $me->{cols} - 2 - length($pSansCodes) - length($me->{_I18N}{minihelp});
   $p .= ' ' x ($pN > 1 ? $pN : 1);
-  $prompt = $pN>2 ? $prompt : do {$prompt =~ s/\000.+//; $prompt };
+  $minihelp = $pN>2 ? $minihelp : do {$minihelp =~ s/\000.+//; $minihelp };
   print $me->{REV};					# reverse video
-  print $p,"  ", $prompt;  				# status line
+  print $p,"  ", $minihelp;  				# status line
   print $me->{NOR};					# normal video
 }
 
@@ -484,7 +520,7 @@ sub close{
   ReadMode 0;
   print "\n";
   $| = $SP || 0;
-  #Did we exit via signal or prompt?
+  #Did we exit via signal or user?
   $RT ? die : return \"foo";
 }
 
@@ -515,15 +551,6 @@ sub help{
   $me->dialog( $help . "\n" . (' 'x$padding) . $cont );
 }
 
-sub dialog{
-  my($me, $msg, $timeout) = @_;
-  $msg = defined($msg) ? $msg : '';
-  $timeout = defined($timeout) ? $timeout : 0;
-  $me->disp_menu( $me->box_text($msg) );
-  $timeout ? sleep($timeout) : getc();
-  $me->remove_menu();
-}
-
 sub max_width{
   my $me = shift;
   my $width = 0;
@@ -531,50 +558,34 @@ sub max_width{
   return $width;
 }
 
-# put a box around some text
-sub box_text{
-  my $me  = shift;
-  my @txt = split(/\n/, $_[0]);
-  my $width = $me->max_width(@txt);
+sub dialog{
+  my($me, $msg, $timeout) = @_;
+  my @txt = defined($msg) ? split(/\n/, $msg) : ();
+  my $w = $me->max_width(@txt);
 
-  my $b = '+' . '=' x ($width + 2) . '+';
-  my $o = join('', map { "| $_" . (' 'x($width-length($_))) ." |\n" } @txt); 
-  "$b\n$o$b\n";
-}
+  #Prepare dialog
+  my $h = '+' . '='x($w+2) . '+';
+  my $d = join('', map { sprintf("%s| %- @{[$w+4]}s |\n",
+				 $me->{_term}->Tgoto('RI',0,4),
+				 $_) } $h, @txt, $h); 
 
-# display a popup menu (or other text)
-sub disp_menu{
-  my $me = shift;
-  my $menu = shift;
+  print $me->{_term}->Tgoto('cm',0, 2),	# move
+        $me->{MENU},		        # set color
+        $d,				# dialog
+        $me->{NOR};			# normal color
 
-  $me->{_menuRows} = @{[split /\n/, $menu]};
-  print $me->{_term}->Tgoto('cm',0, 2);	# move
-  print $me->{MENU};					# set color
-  my $x = $me->{_term}->Tgoto('RI',0,4);		# 4 transparent spaces
-  $menu =~ s/^\s*/$x/gm;
-  print $menu;
-  print $me->{NOR};					# normal color
-}
-
-# remove popup and repaint
-sub remove_menu{
-  my $me = shift;
-
-  my $s = $me->{_menuRows} +2;
+  defined($timeout) ? sleep($timeout) : getc();
 
   #Allow wipe of incomplete/paused output.
-  my $pause = $me->{pause};
-  $me->{pause} = undef;
+  local($me->{pause});
 
+  #XXX Use full refresh if _grep for simple accurate solution?
   # Fractional restoration instead of full refresh
-  foreach my $n (2 .. $s){
+  foreach my $n (2 .. scalar(@txt)+3){
     print $me->{_term}->Tgoto('cm', 0, $n);		# move
     print $me->{_term}->Tputs('ce');			# clear line
     $me->line($n);
   }
-
-  #Reset pause
-  $me->{pause} = $pause;
 }
 
 sub flush_buffer{
@@ -606,8 +617,22 @@ sub refresh{
     $me->line($n+$me->{_cursor}) if			# XXX w/o cursor messy
       $me->{_cursor}+$me->{rows}+$n <= $me->{_txtN}     # after menu & refresh
   }
+  $me->scrollBar() if $me->{scrollBar};
 }
 
+sub scrollBar{
+  my $me = shift;
+  my $mark = sprintf("%i", $me->{_cursor} / $me->{_txtN} * $me->{rows});
+  my $pages = sprintf("%i", $me->{_txtN}/$me->{rows});
+  my $thumb = int($me->{rows}/$pages);
+
+  for my $n (0 .. $me->{rows} -1){
+    print $me->{_term}->Tgoto('cm', $me->{cols}+1, $n);
+    print $n>=$mark && $n<$mark+$thumb ? ' ' : "$me->{REV} $me->{NOR}";
+  }
+}
+
+
 sub line{
   my $me = shift;
   my $n  = shift;
@@ -647,18 +672,14 @@ sub line{
     $me->{_search} ne '';
 
   #Line numbering & search status
-  my $info = $me->{statusCol} && !$me->{lineNo} ?
-    ($matched ? '*' : ' ') :''; 
+  my $info = $me->{statusCol} && !$me->{lineNo} ? ($matched ? '*' : ' ') : ''; 
   $info = sprintf("% 8s", 
 		  $me->{fold} ? ($me->{_lineNo}->[$n]||-1) : 
 				(defined($me->{_text}[$n]) ? $n+1 : '')
 		 ) if $me->{lineNo};
-  $_ = ($me->{statusCol} && $matched ? $me->{REV} : '').
-    $info.
-      ($me->{statusCol} && $matched ? $me->{NOR} : '').
-	($me->{lineNo} ? ' ' : '').
-	  $_;
-
+  $_ = ($me->{Statuscol} && $matched ? $me->{REV} : ''). $info.
+       ($me->{statusCol} && $matched ? $me->{NOR} : '').
+       ($me->{lineNo} ? ' ' : ''). $_;
   print;
 
   if( $pausey ){
@@ -672,7 +693,6 @@ sub down_lines{
   my $n  = shift;
   my $t  = $me->{_term};
 
-#  for(my $i=1; $i<=$n; $i++){
   LINE: for(1..$n){
     if( $me->{_end} >= $me->{_txtN}-1 ){
       exit if $me->{eof} && ref($me->{text}) ne 'CODE';
@@ -691,14 +711,16 @@ sub down_lines{
 	print $t->Tputs('sf');				# scroll
 	print $t->Tgoto('cm', 0, $me->{rows} - 1);	# move
       }
-
       print $t->Tputs('ce');				# clear line
 
       #Skip cursor ahead to matching line if in grep mode
       if( $me->{_grep} && $me->{_end} < $me->{_txtN} ){
 	until( $me->{_text}->[$me->{_end}] =~
 	       m%$me->{_search}|\cF\c]\cL\cE \[\d+/% ){
-	  $me->{_end}++;
+	  $me->dialog(#"$me->{_end} >= $me->{_txtN} #$me->{_cursor}\n".
+		      'Pagination in grep mode does not work at this time.', 1);
+	  last LINE;
+#	  $me->{_end}++;
 	  $me->{_cursor}++;
 	  if( $me->{_end} >= $me->{_txtN} ){
 	    $me->{cursor} = $me->{_end} = $me->{_txtN};
@@ -710,6 +732,7 @@ sub down_lines{
       $me->{_cursor}++;
     }
   }
+  $me->scrollBar() if $me->{scrollBar};
 }
 sub downhalf {  $_[0]->down_lines( $_[0]->{rows} / 2 ); }
 sub downpage {  $_[0]->down_lines( $_[0]->{rows} );
@@ -728,16 +751,23 @@ sub up_lines{
 
   for (1 .. $n){
     if( $me->{_cursor} <= 0 ){
-      &beep; last;
-    }else{
+      &beep; last; }
+    else{
       print $me->{_term}->Tgoto('cm',0,0);	# move
       print $me->{_term}->Tputs('sr');		# scroll back
 
       #XXX Skip cursor back to matching line if in grep mode
-      #XXX this is tough because we want {rows} matching lines
-      #XXX Requires cache of currently grepped lines, then unshift
-      #XXX as we scroll back until we get {rows} new lines or hit top.
-      #XXX finally, displaying the to {rows} of the cache
+      #Skip cursor back to matching line if in grep mode
+#      if( $me->{_grep} && $me->{_cursor} > 0 ){
+#	until( $me->{_text}->[$me->{_end}] =~
+#	       m%$me->{_search}|\cF\c]\cL\cE \[\d+/% ){
+#	  $me->{_cursor}--;
+#	  if( $me->{_cursor} <= 0 ){
+#	    $me->{cursor} = 0;
+#	    last;
+#	  }
+#	}
+#      }
 
       $me->line( --$me->{_cursor} );
       $me->{_end}--;
@@ -745,6 +775,7 @@ sub up_lines{
   }
 
   print $me->{_term}->Tgoto('cm',0,$me->{rows});		# goto bottom
+  $me->scrollBar() if $me->{scrollBar};
 }
 sub uppage {  $_[0]->up_lines( $_[0]->{rows} ); }
 sub upline {  $_[0]->up_lines( 1 ); }
@@ -761,8 +792,9 @@ sub save_mark{
   my $me = shift;
 
   $me->I18N('status', $me->{BLD}.'*Mark name?*'.$me->{NOR}.$me->{REV});
-  $me->prompt();
+  $me->status();
   $me->{_term}->Tgoto('cm',
+		      #XXX I18N
 		      length('[tp] 100% Bottom Mark name?')+1,
 		      $me->{rows});
   my $mark = ReadKey();
@@ -770,14 +802,14 @@ sub save_mark{
   next if $mark eq "'";
   $me->{_mark}->{$mark} = $me->{_cursor};
   $me->I18N('status', '');
-  $me->prompt();
+  $me->status();
 }
 
 sub goto_mark{
   my $me = shift;
 
   my $mark = ReadKey();
-  return if $mark eq "\cG";
+  return if $mark eq "\cG" or not exists($me->{_mark}->{$mark});
 
   my $jump = $me->{_mark}->{$mark};
   if( $mark eq '^' ){
@@ -811,7 +843,6 @@ sub next_file{
 
 sub jump{
   my $me = shift;
-
   $me->{_cursor} = shift;
   $me->{_end}   = $me->{_cursor} + $me->{rows}; # - 1;
   $me->refresh();
@@ -819,31 +850,25 @@ sub jump{
 
 sub tab_right{
   my $me = shift;
-
   $me->{_left} += 8;
   $me->refresh();
 }
 
 sub tab_left{
   my $me = shift;
-
-  $me->{_left} -= 8;
-  $me->{_left} = 0 if $me->{_left} < 0;
+  $me->{_left} = 0 if ($me->{_left} -= 8) < 0;
   $me->refresh();
 }
 
 sub shift_right{
   my $me = shift;
-
   $me->{_left} += int($me->{cols}/2);
   $me->refresh();
 }
 
 sub shift_left{
   my $me = shift;
-
-  $me->{_left} -= int($me->{cols}/2);
-  $me->{_left} = 0 if $me->{_left} < 0;
+  $me->{_left} = 0 if ( $me->{_left} -= int($me->{cols}/2) ) < 0;
   $me->refresh();
 }
 
@@ -865,21 +890,7 @@ sub search{
   print $me->{HILT};					# set color
   print $mode ? ( $mode > 0 ? '?' : '&' ) : '/';
 
-  while(1){
-    my $l = ReadKey();
-    last if $l eq "\n" || $l eq "\r";
-    if( $l eq "\e" || !defined($l) ){
-      $me->{_search} = '';
-      last;
-    }
-    if( $l eq "\b" || $l eq "\177" ){ #Why not octothorpe? || $l eq '#' ){
-      print "\b \b" if $me->{_search} ne '';
-      substr($me->{_search}, -1, 1, '');
-      next;
-    }
-    print $l;
-    $me->{_search} .= $l;
-  }
+  $me->{_search} = $me->getln() || '';
   print $me->{NOR};					# normal color
   print $me->{_term}->Tgoto('cm', 0, $me->{rows});	# move bottom
   print $me->{_term}->Tputs('ce');			# clear line
@@ -893,6 +904,7 @@ sub search{
 
   $me->{_search} = $prev if $me->{_search} eq '/' && $prev;
 
+  #Jump to first match
   for my $n ( $me->{_cursor} .. $me->{_txtN} -1){	#XXX why offset needed?
     next unless $me->{_text}[$n] =~ /$me->{_search}/i;
  
@@ -975,28 +987,12 @@ sub toggle_fold{
 
 sub write_buffer{
   my $me = shift;
-  my $out;
 
   print $me->{_term}->Tgoto('cm', 0, $me->{rows});	# move bottom
   print $me->{_term}->Tputs('ce');			# clear line
   print "Save to: ";
 
-  while(1){
-    my $l = ReadKey();
-    return if $l eq "\cG";
-    last if $l eq "\n" || $l eq "\r";
-
-    if( !defined($l)| $l eq "\e" || $l eq "\cG" ){
-      return;
-    }
-    if( $l eq "\b" || $l eq "\177" ){
-      print "\b \b" if $out ne '';
-      substr($out, -1, 1, '');
-      next;
-    }
-    print $l;
-    $out .= $l;
-  }
+  my $out = $me->{_search} = $me->getln();
   if( ! -e $out && open(OUT, '>', $out) ){
     print OUT join($/, @{$me->{_text}});
     CORE::close(OUT);
@@ -1006,6 +1002,31 @@ sub write_buffer{
   }
 }
 
+sub open_file{
+  my $me = shift;
+
+  print $me->{_term}->Tgoto('cm', 0, $me->{rows});	# move bottom
+  print $me->{_term}->Tputs('ce');			# clear line
+  print "Examine: ";
+
+  my $file = $me->getln();
+  unless( -e $file ){
+    $me->dialog( sprintf("%s: $file", $me->{_I18N}{404}) );
+    return;
+  }
+  unless( open(IN, '<', $file) ){
+    $me->dialog($!);
+    return;
+  }
+  my $N = $me->get_fileN();
+  $me->set_fileN($N+1);
+  $me->add_text(sprintf("======== \cF\c]\cL\cE [%i/..] %s ========\n",
+			$N, $file), <IN>);
+}
+
+sub get_fileN{ $_[0]->{_fileN} }
+sub set_fileN{ $_[0]->{_fileN} = $_[1] }
+
 
 sub dumb_mode{
   my $me = shift;
@@ -1224,6 +1245,8 @@ descriptions are available in L<tp>.
 
 =item &write_buffer - C<:w>
 
+=item &open_file - C<:e>
+
 =back
 
 =head3 Navigation
@@ -1326,25 +1349,23 @@ C<I18N> method to replace the default text or save text for your own interface.
     my $help = $t->I18N('help');
 
     #Minimal status line
-    $t->I18N('prompt', "<h> help");
+    $t->I18N('minihelp', "<h> help");
 
 Current text elements available for customization are:
 
     404        - search text not found dialog
-    bottom     - prompt line end of file indicator
     continue   - text to display at the bottom of the help dialog
     help       - help dialog text, a list of keys and their functions
-    prompt     - displayed at the bottom of the screen
+    minihelp   - basic instructions displayed at the bottom of the screen
     status     - brief message to include in the status line
-    top        - prompt line start of file indicator
-    bottom     - prompt line end of file indicator
+    top        - start of file prompt
+    bottom     - end of file prompt
     searchwrap - message that pager is about to loop for more matches
-    nowrap     - notice that missing Text::Wrap prevents folding toggle
 
-I<status> is intended for sharing short messages not worthy of a dialog
-e.g; when debugging. You will need to call the C<prompt> method after
-setting it to refresh the status line of the display, then void I<status>
-and call C<prompt> again to clear the message.
+I<prompt> is intended for sharing short messages not worthy of a dialog
+e.g; when debugging. You will need to call the C<status> method after
+setting it to refresh the status line of the display, then void I<prompt>
+and call C<status> again to clear the message.
 
 =head3 Scalability
 
